summaryrefslogtreecommitdiffstats
path: root/src/extras/frontendoption.cpp
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/extras/frontendoption.cpp5
1 files changed, 4 insertions, 1 deletions
diff --git a/src/extras/frontendoption.cpp b/src/extras/frontendoption.cpp
index bfeca848..51814f35 100644
--- a/src/extras/frontendoption.cpp
+++ b/src/extras/frontendoption.cpp
@@ -43,10 +43,13 @@ GetNumberOfMenuOptions(int screen)
return Rows;
}
// Used before reloading in InitialiseChangedLanguageSettings and debugmenu
void
RemoveCustomFrontendOptions()
{
+ if (numCustomFrontendOptions == 0)
+ return;
+
for (int i = 0; i < MENUPAGES; i++) {
for (int j = 0; j < NUM_MENUROWS; j++) {
if (aScreens[i].m_aEntries[j].m_Action == MENUACTION_TRIGGERFUNC) {
@@ -43,10 +43,13 @@ GetNumberOfMenuOptions(int screen)
return Rows;
}
-// Used before reloading in InitialiseChangedLanguageSettings and debugmenu
+// Used before populating options, but effective in InitialiseChangedLanguageSettings and debugmenu
void
RemoveCustomFrontendOptions()